import router from "./router";
import store from "./store";
import { Message } from "element-ui";
import NProgress from "nprogress";
import "nprogress/nprogress.css";
import { getToken } from "@/utils/auth";
import { isRelogin } from "@/utils/request";

NProgress.configure({ showSpinner: false });

const whiteList = ["/login", "/register"];

router.beforeEach((to, from, next) => {
  NProgress.start();
  if (window.location.href.includes("clienttoken=")) {
    var reg = new RegExp(/[?&]clienttoken=([^&#]+)/);
    var c = window.location.href.match(reg);
    const clienttoken = c && c[1];
    // console.log("clienttoken:", clienttoken);
    if (store.getters.roles.length === 0) {
      isRelogin.show = true;
      store.dispatch("SingleSignOnGetInfo",{clientToken:clienttoken}).then(res => {
        isRelogin.show = false;
        let url = window.location.href;
        var modifiedUrl = url.replace(/(\?appid&clienttoken=)[^&#]+/, '');
        // console.log(modifiedUrl,'modifiedUrl');
        window.location.href = modifiedUrl;
        // store.dispatch("GenerateRoutes").then((accessRoutes) => {
        //   // 根据roles权限生成可访问的路由表
        //   router.addRoutes(accessRoutes); // 动态添加可访问路由表
        //   next({ ...to, replace: true }); // hack方法 确保addRoutes已完成
        // });
        if (store.getters.roles.length === 0) {
          isRelogin.show = true;
          // 判断当前用户是否已拉取完user_info信息
          store
            .dispatch("GetInfo")
            .then(() => {
              isRelogin.show = false;
              store.dispatch("GenerateRoutes").then((accessRoutes) => {
                // 根据roles权限生成可访问的路由表
                router.addRoutes(accessRoutes); // 动态添加可访问路由表
                next({ ...to, replace: true }); // hack方法 确保addRoutes已完成
              });
            })
            .catch((err) => {
              store.dispatch("LogOut").then(() => {
                Message.error(err);
                next({ path: "/" });
              });
            });
        }
      }).catch((err) => {
        store.dispatch("LogOut").then(() => {
          Message.error(err);
          location.href = process.env.VUE_APP_BASE_API + "/system/singlelogin/login"
        });
      });
    } else {
      next();
    }
  } else if (window.location.href.includes("userToken=") && window.location.href.includes("signature=") && window.location.href.includes("timespan=")) {
    var regOne = new RegExp(/[?&]timespan=([^&#]+)/);
    var regTwo = new RegExp(/[?&]signature=([^&#]+)/);
    var regThree = new RegExp(/[?&]userToken=([^&#]+)/);
    const queryOne = window.location.href.match(regOne);
    const queryTwo = window.location.href.match(regTwo);
    const queryThree = window.location.href.match(regThree);
    const timespan = queryOne && queryOne[1];                       // 时间戳
    const signature = queryTwo && queryTwo[1];                      // 签名
    const userToken = queryThree && queryThree[1];                  // 用户令牌
    let info = {
      userToken,
      signature,
      timespan
    }
    if (store.getters.roles.length === 0) {
      isRelogin.show = true;
      store.dispatch("governmentLogin",info).then(res => {
        isRelogin.show = false;

        if (store.getters.roles.length === 0) {
          // isRelogin.show = true;
          let url = window.location.href;
          var modifiedUrl = url.replace(/[\?&](timespan|signature|userToken)=.*?(#\/|$)/g, '');
          // console.log(modifiedUrl,'modifiedUrl');
          window.location.href = modifiedUrl;
          // 判断当前用户是否已拉取完user_info信息
          store
            .dispatch("GetInfo")
            .then(() => {
              // isRelogin.show = false;
              store.dispatch("GenerateRoutes").then((accessRoutes) => {
                // 根据roles权限生成可访问的路由表
                router.addRoutes(accessRoutes); // 动态添加可访问路由表
                next({ ...to, replace: true }); // hack方法 确保addRoutes已完成
              });
            })
            .catch((err) => {
              store.dispatch("LogOut").then(() => {
                Message.error(err);
                next({ path: "/" });
              });
            });
        }
      }).catch((err) => {
        console.log(err);
        // store.dispatch("LogOut").then(() => {
        //   Message.error(err);
        //   location.href = "https://qyt.sipac.gov.cn/sipsg-enterprise-mobile-manage/#/login"
        // });
      });
    }
  }
  //  else if(window.location.href.includes("clienttoken=")){

  // } 
  else if (getToken()) {
    to.meta.title && store.dispatch("settings/setTitle", to.meta.title);
    /* has token*/
    if (to.path === "/login") {
      next({ path: "/" });
      NProgress.done();
    } else if (whiteList.indexOf(to.path) !== -1) {
      next();
    } else {
      if (store.getters.roles.length === 0) {
        isRelogin.show = true;
        // 判断当前用户是否已拉取完user_info信息
        store
          .dispatch("GetInfo")
          .then(() => {
            isRelogin.show = false;
            store.dispatch("GenerateRoutes").then((accessRoutes) => {
              // 根据roles权限生成可访问的路由表
              router.addRoutes(accessRoutes); // 动态添加可访问路由表
              next({ ...to, replace: true }); // hack方法 确保addRoutes已完成
            });
          })
          .catch((err) => {
            store.dispatch("LogOut").then(() => {
              Message.error(err);
              next({ path: "/" });
            });
          });
      } else {
        next();
      }
    }
  } else {
    // 没有token
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免登录白名单，直接进入
      next();
    } else {
      next(`/login?redirect=${encodeURIComponent(to.fullPath)}`); // 否则全部重定向到登录页
      NProgress.done();
    }
    // store.dispatch("LogOut").then(() => {
    //   Message.error(err);
    //   location.href = process.env.VUE_APP_BASE_API + "/system/singlelogin/login"
    // });
  }
});

router.afterEach(() => {
  NProgress.done();
});
